# -*- coding: utf8 -*-
'''
DB MODULE - ODBC for TSQL
*******************************
***  DB MODULE - ODBC for TSQL
*******************************
$RCSfile: dbmod_odbc_tsql.py,v $
$Revision: 1284 $
$Author: j.holetschek $
$Date: 2013-03-07 13:52:20 +0100 (Do, 07 Mrz 2013) $

A native biocase.wrapper database module to access MS SQL Server databases.
Basedon pymssql
http://pymssql.sourceforge.net/
'''

from biocase.wrapper.errorclasses		import DbModuleMissingError, ConnectionError
from biocase.wrapper.sql.base 			import sqlBase
from biocase.wrapper.dbmod.base_dbmod	import DBBasemodule

import logging
log = logging.getLogger("pywrapper.dbmod")

#############################################
#
# CUSTOMIZATION for SQL Server
#
# OVERLOAD BASE CLASSES AND OTHER METHODS
#
#############################################

# uses inherited ANSI SQL apart from the following.
sqlBase.templates['attribute'] = '[#1].[#2]'
sqlBase.templates['table'] = '[#1]'
sqlBase.templates['select-limit'] = 'SELECT DISTINCT TOP #3 #1 FROM #2'
sqlBase.templates['count-distinct'] = 'COUNT(DISTINCT #1)'

# Works only with SQL Server 2012 (or later)
sqlBase.templates['select-limit-offset'] = 'SELECT DISTINCT #1 FROM #2 OFFSET #4 ROWS FETCH NEXT #3 ROWS ONLY'


class DBmodule(DBBasemodule):
    __version__ = '0.1 using pymssql ?'
    __dbmod__ = u'pymssql Server module'

    def __init__(self, psfObj):
        # call createDBconnection method
        DBBasemodule.__init__(self, psfObj)
        # dont use parameters but integrate all parameters into SQL strings:
        self.trans.integrateParametersInSQLString()

    # ------------------   FUNCTION OVERLOAD OF BASE DBMOD MODULE   ------------------
    def createDBconnection(self):
        try:
            import pymssql
        except:
            raise DbModuleMissingError('pymssql')
        self.__class__.__version__ = self.__class__.__version__[:-1] + pymssql.__version__
        # connect
        try:
            return pymssql.connect(host=self.psfObj.dbIP, user=self.psfObj.user, password=self.psfObj.password, database=self.psfObj.database)
        except:
            raise ConnectionError()

    def execSQL(self, sql, paras=None):
        res = []
        for rec in DBBasemodule.execSQL(self, sql, paras):
            res += [tuple([unicode(column, self.psfObj.encoding) if isinstance(column, str) else column for column in rec])]
        return res

    def getTables(self):
        tables = []
        self.c = self.conn.cursor()
        self.c.execute("SELECT name FROM sysobjects where type in ('U', 'V') and status > 0")
        for t in self.c.fetchall():
            tables.append(str(t[0]))
        self.c.close()
        return tables

    def getColumns(self, _table):
        columns = []
        self.c = self.conn.cursor()
        try:
            self.c.execute("SELECT COLUMN_NAME FROM INFORMATION_SCHEMA.COLUMNS where table_name = '%s'" % (_table))
            for c in self.c.fetchall():
                columns.append(str(c[0]))
        except:
            log.error("Couldn't retrieve column info for table " + _table)
        finally:
            self.c.close()
        return columns

    def hasMetaInfo(self):
        return True
