# -*- coding: utf8 -*-
'''
**********************************************
*       P R O T O C O L - B A S E - C L A S S
*       for any protocol
**********************************************
$RCSfile: base_protocol.py,v $
$Revision: 1255 $
$Author: j.holetschek $
$Date: 2012-12-21 14:02:18 +0100 (Fr, 21. Dez 2012) $

'''

from biocase.wrapper.errorclasses import PyWrapperError

import biocase.configuration
cfg = biocase.configuration.Cfg()

import logging
log = logging.getLogger("pywrapper.protocol")
# this logger is used to log requests!
logRequestOnly = logging.getLogger("pywrapper.protocol.request")

class ProtocolBaseClass:
    '''The main protocol class accepting a standard API and managing requests and responses.'''
    NAME = "abstract protocol"

    def __init__(self, dsaObj, diagnosticsHandler, RequestClass, ResponseClass):
        self.dsaObj = dsaObj
        self.requestObj = RequestClass(dsaObj)
        self.responseObj = ResponseClass(dsaObj, diagnosticsHandler)
        # please set this when database was used
        self.dbmodVersion = None

    def parseRequest(self, args):
        '''Get request args from parameter or CGI and create & process a request object.
        Pass the specific request class to be used with the method.'''
        self.requestObj.parseRequest(args)

    def doResponse(self, stream, encoding, httpHeader):
        '''Process request and print out the response into the given stream.'''
        try:
            log.debug("DO_RESPONSE: process request")
            self.processRequest()
        except PyWrapperError:
            log.info("Request processing failed")
        except Exception, ex:
            log.error("An error occurred during processing the request.")
            log.error(ex)
        try:
            log.debug("DO_RESPONSE: postprocess")
            self.responseObj.postprocessMessage(self.requestObj, self.dbmodVersion)
        except PyWrapperError:
            log.info("Message postprocessing failed")
        except:
            log.error("UNKNOWN ERROR DURING MESSAGE POSTPROCSSING")
        try:
            log.debug("DO_RESPONSE: printResponse")
            self.responseObj.printResponse(stream, encoding, httpHeader)
        except PyWrapperError:
            log.info("Sending message response failed")
        except:
            log.error("UNKNOWN ERROR WHILE RESPONDING THE MESSAGE")
        try:
            log.debug("DO_RESPONSE: logging request")
            self.logRequest()
        except PyWrapperError:
            log.info("Request logging failed")
        except:
            log.error("UNKNOWN ERROR DURING REQUEST LOGGING")

    def processRequest(self):
        '''Override this to implement the operational logic to process a request.'''
        raise "PLEASE IMPLEMENT IN SUBCLASS"

    def logRequest(self):
        '''Basic request logging for all protocolls. Implement logProtocolSpecific() if other protocols want to log more information'''
        try:
            specific = self.logProtocolSpecific()
        except:
            specific = "LogError"
        logRequestOnly.info("%s [%s] %s %s" % (self.psfObj.sourcename.upper(), self.__class__.NAME, self.requestObj.remoteHost, specific))

    def logProtocolSpecific(self):
        '''Override this if other protocols want to log more information about a request and its response'''
        return ""

    def getPsfObj(self):
        return self.dsaObj.getPSFObj()
    psfObj = property(getPsfObj)
