#!C:\Programme\Python25\python.exe
# -*- coding: UTF-8 -*-
import os, sys
from os.path import join, exists, getsize, splitext
from datetime import datetime

# ***** include the biocase.lib directory in the python sys path for importing *****
execfile(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir, 'lib', 'biocase', 'adjustpath.py')))

import simplejson as json
from biocase.wrapper.protocol.inventory.inventory_protocol import ProtocolClass as InventoryProtocolClass
from biocase.archive.general import read_inventory, list_archives_for_schema, drop_archives, ns_dataset_aware, sizeof_fmt, fmt
from biocase.configtool.general import dsaObj, form, dsa, schema, action, log
import biocase.configuration
cfg = biocase.configuration.Cfg()

#form = cgi.FieldStorage()
#dsa = form.getvalue('dsa')
#schema = form.getvalue('schema')
#action = form.getvalue("action")

archivePath = join(cfg.archiveWorkLocator, dsa) + os.sep
dldPath = join(cfg.archiveDownloadLocator, dsa) + os.sep
proc_dwca = archivePath + "DwCA.proc"
log_dwca = archivePath + "DwCA.log"
if schema is not None:
    config = archivePath + schema + ".config.xml"
    proc_xml = archivePath + schema + ".proc"
    log = archivePath + schema + ".log"
    faf = dldPath + schema + '.zip'

print('Content-Type: text/html\n')

# Print 30 last lines of log files
if action == "showlog":
    # First, print log
    if exists(log):
        size = getsize(log)
        f = open(log)
        # Only read 4KB at the end
        f.seek(max(size - 4096, 0))
        lines = f.readlines()
        f.close()
        # Restrict output to 25 lines
        if len(lines) > 30:
            sys.stdout.write("(continued)<br>")
        for line in lines[-30:]:
            line = line[:-1]
            if line != '' and line[:4] != "INFO":
                line = '<font color="%s">%s</font>' % ('#FF0000' if line.startswith('ERROR') else '#FF6600', line)
            # Use sys.out here in order to allow printing without newline or space
            sys.stdout.write(line + '&nbsp;<br>')
        # Add line that indicates finishing
        if not exists(proc_xml):
            if exists(proc_dwca):
                print "XML generation ended, conversion will be started..."
            else:
                print "... processing ended."
    else:
        print("Log file not found: " + log)

if action == "archiveexists":
    if list_archives_for_schema(dsa, schema):
        print "true"
    else:
        print "false"

if action == "list":
    # First, list archives
    archives = []
    url_rel = cfg.archiveDownloadLocator[len(cfg.wwwLocator) + 1:].replace('\\', '/')
    baseURL = cfg.getWebappURL() + url_rel + '/' + dsa + '/'

    for aname, (schema, NS, dataset, records, dropped, size, modified, _dummy) in read_inventory(dsa).iteritems():
        # if NS is not ABCD2.06/HISPID5, remove it
        # This way, the interface can detect which archives an be converted to DwC-A
        srecs, sdropped = fmt(records, dropped if dropped else '')
        archives += [(dataset, schema, NS if NS in ns_dataset_aware else None, aname, baseURL + aname,
                      datetime.fromtimestamp(modified).strftime("%y-%m-%d %H:%M"), sizeof_fmt(size), srecs, sdropped)]

    # Proc and Log files of aborted runs
    log = []
    proc = None
    for fname in  os.listdir(archivePath):
        fname_head = splitext(fname)[0]
        if fname.endswith('.proc'):
            proc = fname_head
        elif fname.endswith('.log'):
            addit = False
            if getsize(join(archivePath, fname)) > 0:  # Ignore empty files
                if exists(join(dldPath, fname)):
                    # Same file exists in download folder: Only list if it's not the same file
                    a = os.stat(join(archivePath, fname))
                    d = os.stat(join(dldPath, fname))
                    if (a.st_size != d.st_size) or (d.st_mtime - a.st_mtime > 5):
                        addit = True
                else:
                    # Doesn't exist in download folder: add to list
                    addit = True
            if addit:
                log += [fname_head]

    # Make up result dictionary; only add incomplete log file if it is not the running process
    # Important archives need to be sorted by schema (and dataset title subsequently)
    res = {'archive': sorted(archives, key=lambda arch: arch[1] + arch[3]), 'proc': proc, 'log': [name for name in log if name != proc]}

    # Return dictionary as JSON
    #print res
    print json.dumps(res)

if action == "list_datasets":
    try:
        invObj = InventoryProtocolClass(dsaObj, None)
        invObj.parseRequest(schema)
        invObj.processRequest()
        datasets = invObj.datasets
        if datasets == []:
            print "Dataset list could not be retrieved or is empty. \nPlease make sure that the DB connection is OK and that this mapping returns any results!"
        else:
            html = ""
            for dataset in datasets:
                html += "<option>%s</option>" % dataset.replace(" ", "&nbsp;")  # replace spaces with non-breakable spaces
            print json.dumps(html)
    except Exception, err:
        print "Error trying to load dataset list: %s" % err.msg

    #    print "<option>AlgaTerra</option> <option>AlgaTerraMovies</option> <option>Biosphärenpark Wienerwald - Wiener Steinhofgründe</option> <option selected>BoBO - Botanic Garden Berlin BDI Observations</option> <option>Colección de Monocotiledóneas Mexicanas (UAM-I)</option> <option>Herbarium Berolinense</option>"

if action == "remove":
    try:
        logfile = form.getvalue('logfile')
        filenames = [unicode(fname, 'utf-8') for fname in form.getlist('filename')]

        # If failed log for the schema is to be removed: easy
        if logfile == 'true':
            os.remove(archivePath + filenames[0] + '.log')
            print "Log file was removed."

        else:
            if filenames:
                cnt = drop_archives(dsa, True, filenames)
            else:
                cnt = drop_archives(dsa, True, schema)
            print "%i file%s been removed." % (cnt, 's have' if cnt > 1 else ' has')

    except Exception, err:
        print err
